==> idyntree-3.2.2.dev20-cp38-cp38-manylinux_2_24_x86_64.whl: idyntree/lib/cmake/iDynTree/iDynTreeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "iDynTree::idyntree-core" for configuration "Release"
set_property(TARGET iDynTree::idyntree-core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-core.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-core )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-core "${_IMPORT_PREFIX}/lib/libidyntree-core.a" )

# Import target "iDynTree::idyntree-model" for configuration "Release"
set_property(TARGET iDynTree::idyntree-model APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-model PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-model.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-model )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-model "${_IMPORT_PREFIX}/lib/libidyntree-model.a" )

# Import target "iDynTree::idyntree-sensors" for configuration "Release"
set_property(TARGET iDynTree::idyntree-sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-sensors PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-sensors.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-sensors )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-sensors "${_IMPORT_PREFIX}/lib/libidyntree-sensors.a" )

# Import target "iDynTree::idyntree-modelio-xml" for configuration "Release"
set_property(TARGET iDynTree::idyntree-modelio-xml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-modelio-xml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-modelio-xml.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-modelio-xml )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-modelio-xml "${_IMPORT_PREFIX}/lib/libidyntree-modelio-xml.a" )

# Import target "iDynTree::idyntree-modelio-urdf" for configuration "Release"
set_property(TARGET iDynTree::idyntree-modelio-urdf APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-modelio-urdf PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-modelio-urdf.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-modelio-urdf )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-modelio-urdf "${_IMPORT_PREFIX}/lib/libidyntree-modelio-urdf.a" )

# Import target "iDynTree::idyntree-estimation" for configuration "Release"
set_property(TARGET iDynTree::idyntree-estimation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-estimation PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-estimation.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-estimation )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-estimation "${_IMPORT_PREFIX}/lib/libidyntree-estimation.a" )

# Import target "iDynTree::idyntree-solid-shapes" for configuration "Release"
set_property(TARGET iDynTree::idyntree-solid-shapes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-solid-shapes PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-solid-shapes.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-solid-shapes )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-solid-shapes "${_IMPORT_PREFIX}/lib/libidyntree-solid-shapes.a" )

# Import target "iDynTree::idyntree-high-level" for configuration "Release"
set_property(TARGET iDynTree::idyntree-high-level APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-high-level PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-high-level.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-high-level )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-high-level "${_IMPORT_PREFIX}/lib/libidyntree-high-level.a" )

# Import target "iDynTree::idyntree-inverse-kinematics" for configuration "Release"
set_property(TARGET iDynTree::idyntree-inverse-kinematics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-inverse-kinematics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-inverse-kinematics.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-inverse-kinematics )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-inverse-kinematics "${_IMPORT_PREFIX}/lib/libidyntree-inverse-kinematics.a" )

# Import target "iDynTree::idyntree-optimalcontrol" for configuration "Release"
set_property(TARGET iDynTree::idyntree-optimalcontrol APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-optimalcontrol PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-optimalcontrol.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-optimalcontrol )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-optimalcontrol "${_IMPORT_PREFIX}/lib/libidyntree-optimalcontrol.a" )

# Import target "iDynTree::idyntree-visualization" for configuration "Release"
set_property(TARGET iDynTree::idyntree-visualization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-visualization PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-visualization.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-visualization )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-visualization "${_IMPORT_PREFIX}/lib/libidyntree-visualization.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> idyntree-4.2.1.dev59-cp38-cp38-manylinux_2_24_x86_64.whl: idyntree/lib/cmake/iDynTree/iDynTreeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "iDynTree::idyntree-core" for configuration "Release"
set_property(TARGET iDynTree::idyntree-core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-core.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-core )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-core "${_IMPORT_PREFIX}/lib/libidyntree-core.a" )

# Import target "iDynTree::idyntree-model" for configuration "Release"
set_property(TARGET iDynTree::idyntree-model APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-model PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-model.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-model )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-model "${_IMPORT_PREFIX}/lib/libidyntree-model.a" )

# Import target "iDynTree::idyntree-sensors" for configuration "Release"
set_property(TARGET iDynTree::idyntree-sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-sensors PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-sensors.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-sensors )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-sensors "${_IMPORT_PREFIX}/lib/libidyntree-sensors.a" )

# Import target "iDynTree::idyntree-modelio-xml" for configuration "Release"
set_property(TARGET iDynTree::idyntree-modelio-xml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-modelio-xml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-modelio-xml.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-modelio-xml )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-modelio-xml "${_IMPORT_PREFIX}/lib/libidyntree-modelio-xml.a" )

# Import target "iDynTree::idyntree-modelio" for configuration "Release"
set_property(TARGET iDynTree::idyntree-modelio APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-modelio PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-modelio.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-modelio )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-modelio "${_IMPORT_PREFIX}/lib/libidyntree-modelio.a" )

# Import target "iDynTree::idyntree-estimation" for configuration "Release"
set_property(TARGET iDynTree::idyntree-estimation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-estimation PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-estimation.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-estimation )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-estimation "${_IMPORT_PREFIX}/lib/libidyntree-estimation.a" )

# Import target "iDynTree::idyntree-solid-shapes" for configuration "Release"
set_property(TARGET iDynTree::idyntree-solid-shapes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-solid-shapes PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-solid-shapes.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-solid-shapes )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-solid-shapes "${_IMPORT_PREFIX}/lib/libidyntree-solid-shapes.a" )

# Import target "iDynTree::idyntree-high-level" for configuration "Release"
set_property(TARGET iDynTree::idyntree-high-level APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-high-level PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-high-level.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-high-level )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-high-level "${_IMPORT_PREFIX}/lib/libidyntree-high-level.a" )

# Import target "iDynTree::idyntree-inverse-kinematics" for configuration "Release"
set_property(TARGET iDynTree::idyntree-inverse-kinematics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-inverse-kinematics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-inverse-kinematics.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-inverse-kinematics )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-inverse-kinematics "${_IMPORT_PREFIX}/lib/libidyntree-inverse-kinematics.a" )

# Import target "iDynTree::idyntree-optimalcontrol" for configuration "Release"
set_property(TARGET iDynTree::idyntree-optimalcontrol APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-optimalcontrol PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-optimalcontrol.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-optimalcontrol )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-optimalcontrol "${_IMPORT_PREFIX}/lib/libidyntree-optimalcontrol.a" )

# Import target "iDynTree::idyntree-visualization" for configuration "Release"
set_property(TARGET iDynTree::idyntree-visualization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(iDynTree::idyntree-visualization PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libidyntree-visualization.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS iDynTree::idyntree-visualization )
list(APPEND _IMPORT_CHECK_FILES_FOR_iDynTree::idyntree-visualization "${_IMPORT_PREFIX}/lib/libidyntree-visualization.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
